aboutsummaryrefslogtreecommitdiffstats
path: root/epan
diff options
context:
space:
mode:
authorMartin Mathieson <martin.mathieson@keysight.com>2020-08-31 12:39:37 +0100
committerMartin Mathieson <martin.mathieson@keysight.com>2020-08-31 12:39:37 +0100
commit2999b7f6b378298001884fa0d95aa108ff0c5f3d (patch)
tree9126d40938183ef0fa4888e3bf54c3626d86cb23 /epan
parent73ff25185cc24791138de4752258a13eefe53484 (diff)
More spelling fixes, part 2 of 2nd pass of dissectors.
Diffstat (limited to 'epan')
-rw-r--r--epan/dissectors/packet-dis.c44
-rw-r--r--epan/dissectors/packet-docsis.c4
-rw-r--r--epan/dissectors/packet-dpnet.c2
-rw-r--r--epan/dissectors/packet-dtn.c6
-rw-r--r--epan/dissectors/packet-dvb-s2-table.c2
-rw-r--r--epan/dissectors/packet-ecp.c2
-rw-r--r--epan/dissectors/packet-epl.c2
-rw-r--r--epan/dissectors/packet-fc00.c12
-rw-r--r--epan/dissectors/packet-fcdns.c2
-rw-r--r--epan/dissectors/packet-fcfcs.c2
-rw-r--r--epan/dissectors/packet-fcswils.c2
-rw-r--r--epan/dissectors/packet-forces.c4
-rw-r--r--epan/dissectors/packet-geonw.c2
-rw-r--r--epan/dissectors/packet-gfp.c4
-rw-r--r--epan/dissectors/packet-gsm_r_uus1.c8
-rw-r--r--epan/dissectors/packet-hartip.c4
-rw-r--r--epan/dissectors/packet-iec104.c2
-rw-r--r--epan/dissectors/packet-ieee1905.c28
-rw-r--r--epan/dissectors/packet-ieee80211.c20
-rw-r--r--epan/dissectors/packet-infiniband.c2
-rw-r--r--epan/dissectors/packet-isakmp.c2
-rw-r--r--epan/dissectors/packet-isis-lsp.c2
-rw-r--r--epan/dissectors/packet-isis.c2
-rw-r--r--epan/dissectors/packet-jdwp.c2
-rw-r--r--epan/dissectors/packet-ldp.c2
-rw-r--r--epan/dissectors/packet-lldp.c2
-rw-r--r--epan/dissectors/packet-llrp.c4
-rw-r--r--epan/dissectors/packet-lnet.c2
28 files changed, 86 insertions, 86 deletions
diff --git a/epan/dissectors/packet-dis.c b/epan/dissectors/packet-dis.c
index 98ab7fa97d..39cea0c100 100644
--- a/epan/dissectors/packet-dis.c
+++ b/epan/dissectors/packet-dis.c
@@ -4448,9 +4448,9 @@ static int hf_dis_entity_orientation_phi = -1;
static int hf_dis_entity_linear_velocity_x = -1;
static int hf_dis_entity_linear_velocity_y = -1;
static int hf_dis_entity_linear_velocity_z = -1;
-static int hf_dis_entity_linear_aceleration_x = -1;
-static int hf_dis_entity_linear_aceleration_y = -1;
-static int hf_dis_entity_linear_aceleration_z = -1;
+static int hf_dis_entity_linear_acceleration_x = -1;
+static int hf_dis_entity_linear_acceleration_y = -1;
+static int hf_dis_entity_linear_acceleration_z = -1;
static int hf_dis_entity_entity_angular_velocity_x = -1;
static int hf_dis_entity_entity_angular_velocity_y = -1;
static int hf_dis_entity_entity_angular_velocity_z = -1;
@@ -4681,7 +4681,7 @@ static gint ett_entity_orientation = -1;
static gint ett_entity_marking_text = -1;
static gint ett_aggregate_marking_text = -1;
static gint ett_entity_dead_reckoning_parameters = -1;
-static gint ett_entity_linear_aceleration = -1;
+static gint ett_entity_linear_acceleration = -1;
static gint ett_entity_angular_velocity = -1;
static gint ett_environmental_environment_status = -1;
static gint ett_environmental_environment_type = -1;
@@ -4689,7 +4689,7 @@ static gint ett_aggregate_type = -1;
static gint ett_aggregate_center_of_mass = -1;
static gint ett_designator_spot_location = -1;
static gint ett_designator_spot_with_respect_to_designated_entity = -1;
-static gint ett_designator_entity_linear_aceleration = -1;
+static gint ett_designator_entity_linear_acceleration = -1;
@@ -6024,12 +6024,12 @@ static int dissect_DIS_PARSER_ENTITY_STATE_PDU(tvbuff_t *tvb, packet_info *pinfo
proto_tree_add_item(sub_tree, hf_dis_dead_reckoning_other_parameters, tvb, offset, 15, ENC_NA);
offset += 15;
- sub_tree2 = proto_tree_add_subtree(sub_tree, tvb, offset, 12, ett_entity_linear_aceleration, NULL, "Entity Linear Acceleration");
- proto_tree_add_item(sub_tree2, hf_dis_entity_linear_aceleration_x, tvb, offset, 4, ENC_BIG_ENDIAN);
+ sub_tree2 = proto_tree_add_subtree(sub_tree, tvb, offset, 12, ett_entity_linear_acceleration, NULL, "Entity Linear Acceleration");
+ proto_tree_add_item(sub_tree2, hf_dis_entity_linear_acceleration_x, tvb, offset, 4, ENC_BIG_ENDIAN);
offset += 4;
- proto_tree_add_item(sub_tree2, hf_dis_entity_linear_aceleration_y, tvb, offset, 4, ENC_BIG_ENDIAN);
+ proto_tree_add_item(sub_tree2, hf_dis_entity_linear_acceleration_y, tvb, offset, 4, ENC_BIG_ENDIAN);
offset += 4;
- proto_tree_add_item(sub_tree2, hf_dis_entity_linear_aceleration_z, tvb, offset, 4, ENC_BIG_ENDIAN);
+ proto_tree_add_item(sub_tree2, hf_dis_entity_linear_acceleration_z, tvb, offset, 4, ENC_BIG_ENDIAN);
offset += 4;
sub_tree2 = proto_tree_add_subtree(sub_tree, tvb, offset, 12, ett_entity_angular_velocity, NULL, "Entity Angular Velocity");
@@ -6791,12 +6791,12 @@ static int dissect_DIS_PARSER_DESIGNATOR_PDU(tvbuff_t *tvb, packet_info *pinfo,
proto_tree_add_item(tree, hf_dis_padding, tvb, offset, 3, ENC_NA);
offset += 3;
- sub_tree = proto_tree_add_subtree(tree, tvb, offset, 12, ett_designator_entity_linear_aceleration, NULL, "Entity Linear Acceleration");
- proto_tree_add_item(sub_tree, hf_dis_entity_linear_aceleration_x, tvb, offset, 4, ENC_BIG_ENDIAN);
+ sub_tree = proto_tree_add_subtree(tree, tvb, offset, 12, ett_designator_entity_linear_acceleration, NULL, "Entity Linear Acceleration");
+ proto_tree_add_item(sub_tree, hf_dis_entity_linear_acceleration_x, tvb, offset, 4, ENC_BIG_ENDIAN);
offset += 4;
- proto_tree_add_item(sub_tree, hf_dis_entity_linear_aceleration_y, tvb, offset, 4, ENC_BIG_ENDIAN);
+ proto_tree_add_item(sub_tree, hf_dis_entity_linear_acceleration_y, tvb, offset, 4, ENC_BIG_ENDIAN);
offset += 4;
- proto_tree_add_item(sub_tree, hf_dis_entity_linear_aceleration_z, tvb, offset, 4, ENC_BIG_ENDIAN);
+ proto_tree_add_item(sub_tree, hf_dis_entity_linear_acceleration_z, tvb, offset, 4, ENC_BIG_ENDIAN);
offset += 4;
/* need to finish decoding this PDU */
@@ -9512,18 +9512,18 @@ void proto_register_dis(void)
FT_BYTES, BASE_NONE, NULL, 0x0,
NULL, HFILL}
},
- { &hf_dis_entity_linear_aceleration_x,
- {"Entity Linear Aceleration X", "dis.entity_linear_aceleration.x",
+ { &hf_dis_entity_linear_acceleration_x,
+ {"Entity Linear acceleration X", "dis.entity_linear_acceleration.x",
FT_FLOAT, BASE_NONE, NULL, 0x0,
NULL, HFILL}
},
- { &hf_dis_entity_linear_aceleration_y,
- {"Entity Linear Aceleration Y", "dis.entity_linear_aceleration.y",
+ { &hf_dis_entity_linear_acceleration_y,
+ {"Entity Linear acceleration Y", "dis.entity_linear_acceleration.y",
FT_FLOAT, BASE_NONE, NULL, 0x0,
NULL, HFILL}
},
- { &hf_dis_entity_linear_aceleration_z,
- {"Entity Linear Aceleration Z", "dis.entity_linear_aceleration.z",
+ { &hf_dis_entity_linear_acceleration_z,
+ {"Entity Linear acceleration Z", "dis.entity_linear_acceleration.z",
FT_FLOAT, BASE_NONE, NULL, 0x0,
NULL, HFILL}
},
@@ -10439,7 +10439,7 @@ void proto_register_dis(void)
NULL, HFILL }
},
{ &hf_dis_iff_mode_4,
- { "IFF Mode 4 Pseude Crypto", "dis.iff.mode_4",
+ { "IFF Mode 4 Pseudo Crypto", "dis.iff.mode_4",
FT_UINT16, BASE_DEC, VALS(DIS_PDU_IffMode4_Strings), 0x0,
NULL, HFILL }
},
@@ -10503,7 +10503,7 @@ void proto_register_dis(void)
&ett_entity_marking_text,
&ett_aggregate_marking_text,
&ett_entity_dead_reckoning_parameters,
- &ett_entity_linear_aceleration,
+ &ett_entity_linear_acceleration,
&ett_entity_angular_velocity,
&ett_environmental_environment_status,
&ett_environmental_environment_type,
@@ -10511,7 +10511,7 @@ void proto_register_dis(void)
&ett_aggregate_center_of_mass,
&ett_designator_spot_location,
&ett_designator_spot_with_respect_to_designated_entity,
- &ett_designator_entity_linear_aceleration,
+ &ett_designator_entity_linear_acceleration,
&ett_entity_location,
&ett_entity_orientation,
&ett_entity_appearance,
diff --git a/epan/dissectors/packet-dpnet.c b/epan/dissectors/packet-dpnet.c
index 57d664090c..3f0a432e78 100644
--- a/epan/dissectors/packet-dpnet.c
+++ b/epan/dissectors/packet-dpnet.c
@@ -642,7 +642,7 @@ proto_register_dpnet(void)
NULL, HFILL }
},
{ &hf_dpnet_data_cframe_timestamp,
- { "Timestmap", "dpnet.cframe.timestamp",
+ { "Timestamp", "dpnet.cframe.timestamp",
FT_UINT32, BASE_DEC,
NULL, 0,
NULL, HFILL }
diff --git a/epan/dissectors/packet-dtn.c b/epan/dissectors/packet-dtn.c
index 6eb0c06251..5759cfc215 100644
--- a/epan/dissectors/packet-dtn.c
+++ b/epan/dissectors/packet-dtn.c
@@ -3039,11 +3039,11 @@ proto_register_bundle(void)
FT_BOOLEAN, 8, NULL, BLOCK_CONTROL_REPLICATE, NULL, HFILL}
},
{&hf_block_control_transmit_status,
- {"Transmit Status if Block Can't be Processeed", "bundle.block.control.status",
+ {"Transmit Status if Block Can't be Processed", "bundle.block.control.status",
FT_BOOLEAN, 8, NULL, BLOCK_CONTROL_TRANSMIT_STATUS, NULL, HFILL}
},
{&hf_block_control_delete_bundle,
- {"Delete Bundle if Block Can't be Processeed", "bundle.block.control.delete",
+ {"Delete Bundle if Block Can't be Processed", "bundle.block.control.delete",
FT_BOOLEAN, 8, NULL, BLOCK_CONTROL_DELETE_BUNDLE, NULL, HFILL}
},
{&hf_block_control_last_block,
@@ -3123,7 +3123,7 @@ proto_register_bundle(void)
FT_INT32, BASE_DEC, NULL, 0x0, NULL, HFILL}
},
{&hf_bundle_block_previous_hop_scheme,
- {"Previous Hop Secheme", "bundle.block.previous_hop_scheme",
+ {"Previous Hop Scheme", "bundle.block.previous_hop_scheme",
FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL}
},
{&hf_bundle_block_previous_hop_eid,
diff --git a/epan/dissectors/packet-dvb-s2-table.c b/epan/dissectors/packet-dvb-s2-table.c
index e36292797c..a2051e5229 100644
--- a/epan/dissectors/packet-dvb-s2-table.c
+++ b/epan/dissectors/packet-dvb-s2-table.c
@@ -4258,7 +4258,7 @@ void proto_register_dvb_s2_table(void)
NULL, HFILL}
},
{&hf_dvb_s2_table_desc_lowest_assign_id, {
- "Descriptor lowest_assignmant_id", "dvb-s2_table.desc.lowest_assign_id",
+ "Descriptor lowest_assignment_id", "dvb-s2_table.desc.lowest_assign_id",
FT_UINT24, BASE_HEX, NULL, 0x0,
NULL, HFILL}
},
diff --git a/epan/dissectors/packet-ecp.c b/epan/dissectors/packet-ecp.c
index 41c0ad5928..2fd6098b4a 100644
--- a/epan/dissectors/packet-ecp.c
+++ b/epan/dissectors/packet-ecp.c
@@ -123,7 +123,7 @@ static const value_string vdp_tlv_type_vals[] = {
{ VDP_TLV_ASSOC, "Associate" },
{ VDP_TLV_DEASSOC, "DeAssociate" },
{ VDP_TLV_MGRID, "VSI Manager ID" },
- { VDP_TLV_ORG, "Orgnaizationally defined TLV" },
+ { VDP_TLV_ORG, "Organizationally defined TLV" },
{ 0x0, NULL }
};
diff --git a/epan/dissectors/packet-epl.c b/epan/dissectors/packet-epl.c
index e02f3d869a..a548782d0a 100644
--- a/epan/dissectors/packet-epl.c
+++ b/epan/dissectors/packet-epl.c
@@ -6371,7 +6371,7 @@ proto_register_epl(void)
"If you are capturing in networks with multiplexed or slow nodes, this can be useful", &show_soc_flags);
prefs_register_bool_preference(epl_module, "show_duplicated_command_layer", "Show command-layer in duplicated frames",
- "For analysis purposes one might want to show the command layer even if the dissectore assumes a duplicated frame", &show_cmd_layer_for_duplicated);
+ "For analysis purposes one might want to show the command layer even if the dissector assumes a duplicated frame", &show_cmd_layer_for_duplicated);
prefs_register_bool_preference(epl_module, "show_pdo_meta_info", "Show life times and origin PDO Tx/Rx params for PDO entries",
"For analysis purposes one might want to see how long the current mapping has been active for and what OD write caused it", &show_pdo_meta_info);
diff --git a/epan/dissectors/packet-fc00.c b/epan/dissectors/packet-fc00.c
index b9956063b0..cd0b5a8f43 100644
--- a/epan/dissectors/packet-fc00.c
+++ b/epan/dissectors/packet-fc00.c
@@ -188,37 +188,37 @@ proto_register_fc00(void)
},
{ &hf_fc00_auth_challenge,
- { "Auth Challenge", "fc00.auth_challange",
+ { "Auth Challenge", "fc00.auth_challenge",
FT_BYTES, BASE_NONE, NULL, 0x0,
NULL, HFILL }
},
{ &hf_fc00_auth_type,
- { "Auth Type", "fc00.auth_challange.type",
+ { "Auth Type", "fc00.auth_challenge.type",
FT_UINT8, BASE_DEC, NULL, 0x0,
NULL, HFILL }
},
{ &hf_fc00_auth_hash_code,
- { "Auth Hash Code", "fc00.auth_challange.hash_code",
+ { "Auth Hash Code", "fc00.auth_challenge.hash_code",
FT_BYTES, BASE_NONE, NULL, 0x0,
NULL, HFILL }
},
{ &hf_fc00_auth_poly,
- { "Poly1305 Authentication", "fc00.auth_challange.poly1305",
+ { "Poly1305 Authentication", "fc00.auth_challenge.poly1305",
FT_UINT8, BASE_DEC, NULL, 0x80,
NULL, HFILL }
},
{ &hf_fc00_auth_derivations,
- { "Auth Derivations", "fc00.auth_challange.derivations",
+ { "Auth Derivations", "fc00.auth_challenge.derivations",
FT_UINT16, BASE_DEC, NULL, 0x7F,
NULL, HFILL }
},
{ &hf_fc00_auth_additional,
- { "Auth Additional", "fc00.auth_challange.additional",
+ { "Auth Additional", "fc00.auth_challenge.additional",
FT_UINT16, BASE_HEX, NULL, 0x0,
NULL, HFILL }
},
diff --git a/epan/dissectors/packet-fcdns.c b/epan/dissectors/packet-fcdns.c
index 1e0b183d9a..498ded6adb 100644
--- a/epan/dissectors/packet-fcdns.c
+++ b/epan/dissectors/packet-fcdns.c
@@ -390,7 +390,7 @@ static header_field_info hfi_fcdns_req_ip FCDNS_HFI_INIT =
NULL, HFILL};
static header_field_info hfi_fcdns_rjtdetail FCDNS_HFI_INIT =
- {"Reason Code Explanantion", "fcdns.rply.reasondet", FT_UINT8,
+ {"Reason Code Explanation", "fcdns.rply.reasondet", FT_UINT8,
BASE_HEX, VALS (fc_dns_rjt_det_code_val), 0x0, NULL, HFILL};
static header_field_info hfi_fcdns_zone_mbrtype FCDNS_HFI_INIT =
diff --git a/epan/dissectors/packet-fcfcs.c b/epan/dissectors/packet-fcfcs.c
index 5958377b43..9376e01bec 100644
--- a/epan/dissectors/packet-fcfcs.c
+++ b/epan/dissectors/packet-fcfcs.c
@@ -958,7 +958,7 @@ proto_register_fcfcs (void)
{"Reason Code", "fcs.reason", FT_UINT8, BASE_HEX,
VALS (fc_ct_rjt_code_vals), 0x0, NULL, HFILL}},
{ &hf_fcs_rjtdetail,
- {"Reason Code Explanantion", "fcs.reasondet", FT_UINT8, BASE_HEX,
+ {"Reason Code Explanation", "fcs.reasondet", FT_UINT8, BASE_HEX,
VALS (fc_fcs_rjt_code_val), 0x0, NULL, HFILL}},
{ &hf_fcs_vendor,
{"Vendor Unique Reject Code", "fcs.err.vendor", FT_UINT8, BASE_HEX,
diff --git a/epan/dissectors/packet-fcswils.c b/epan/dissectors/packet-fcswils.c
index c8b9ab79a9..0236791596 100644
--- a/epan/dissectors/packet-fcswils.c
+++ b/epan/dissectors/packet-fcswils.c
@@ -2200,7 +2200,7 @@ proto_register_fcswils(void)
NULL, HFILL}},
{ &hf_swils_rjtdet,
- {"Reason Code Explanantion", "swils.rjt.reasonexpl",
+ {"Reason Code Explanation", "swils.rjt.reasonexpl",
FT_UINT8, BASE_HEX, VALS(fc_swils_deterr_val), 0x0,
NULL, HFILL}},
diff --git a/epan/dissectors/packet-forces.c b/epan/dissectors/packet-forces.c
index 2298417f8d..ec03210b9c 100644
--- a/epan/dissectors/packet-forces.c
+++ b/epan/dissectors/packet-forces.c
@@ -87,7 +87,7 @@ static int hf_forces_unknown_tlv = -1;
#define EventNotification 0x05
#define PacketRedirect 0x06
#define Heartbeat 0x0F
-#define AssociationSetupRepsonse 0x11
+#define AssociationSetupResponse 0x11
#define ConfigResponse 0x13
#define QueryResponse 0x14
@@ -239,7 +239,7 @@ static const value_string message_type_vals[] = {
{ EventNotification, "EventNotification" },
{ PacketRedirect, "PacketRedirect" },
{ Heartbeat, "Heartbeat" },
- { AssociationSetupRepsonse, "AssociationSetupRepsonse" },
+ { AssociationSetupResponse, "AssociationSetupResponse" },
{ ConfigResponse, "ConfigResponse" },
{ QueryResponse, "QueryResponse" },
{ 0, NULL},
diff --git a/epan/dissectors/packet-geonw.c b/epan/dissectors/packet-geonw.c
index 476e7b2561..64adcfe30f 100644
--- a/epan/dissectors/packet-geonw.c
+++ b/epan/dissectors/packet-geonw.c
@@ -3530,7 +3530,7 @@ proto_register_geonw(void)
{ &hf_sgeonw_conf, { "Confidence", "geonw.sec.confidence", FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }},
{ &hf_sgeonw_time32, { "Time32", "geonw.sec.time32", FT_UINT32, BASE_DEC, NULL, 0x0, NULL, HFILL }},
{ &hf_sgeonw_lat, { "Latitude", "geonw.sec.lat", FT_INT32, BASE_DEC, NULL, 0x0, NULL, HFILL }},
- { &hf_sgeonw_lon, { "Longiture", "geonw.sec.lon", FT_INT32, BASE_DEC, NULL, 0x0, NULL, HFILL }},
+ { &hf_sgeonw_lon, { "Longitude", "geonw.sec.lon", FT_INT32, BASE_DEC, NULL, 0x0, NULL, HFILL }},
{ &hf_sgeonw_elev, { "Elevation", "geonw.sec.elev", FT_INT16, BASE_CUSTOM, CF_FUNC(display_elevation), 0x0, NULL, HFILL }},
{ &hf_sgeonw_hashedid3, { "Hashed ID 3", "geonw.sec.hashedid3", FT_BYTES, BASE_NONE, NULL, 0x0, NULL, HFILL }},
{ &hf_sgeonw_duration_unit, { "Unit", "geonw.sec.duration.unit", FT_UINT16, BASE_DEC, VALS(sgeonw_duration_unit_names), 0xe000, NULL, HFILL }},
diff --git a/epan/dissectors/packet-gfp.c b/epan/dissectors/packet-gfp.c
index c1b123043a..6a0b9be224 100644
--- a/epan/dissectors/packet-gfp.c
+++ b/epan/dissectors/packet-gfp.c
@@ -134,9 +134,9 @@ static const range_string gfp_upi_data_rvals[] = {
{9, 9, "Transparent DVB ASI"},
{10, 10, "Frame-Mapped IEEE 802.17 Resilient Packet Ring"},
{11, 11, "Frame-Mapped Fibre Channel FC-BBW"},
- {12, 12, "Asycnchronous Transparent Fibre Channel"},
+ {12, 12, "Asynchronous Transparent Fibre Channel"},
{13, 13, "Frame-Mapped MPLS"},
- {14, 14, "Frame-Mapped MPLS (Multicast) [Deprecrated]"},
+ {14, 14, "Frame-Mapped MPLS (Multicast) [Deprecated]"},
{15, 15, "Frame-Mapped OSI network layer protocols (IS-IS, ES-IS, CLNP)"},
{16, 16, "Frame-Mapped IPv4"},
{17, 17, "Frame-Mapped IPv6"},
diff --git a/epan/dissectors/packet-gsm_r_uus1.c b/epan/dissectors/packet-gsm_r_uus1.c
index 707c546c40..7149f66502 100644
--- a/epan/dissectors/packet-gsm_r_uus1.c
+++ b/epan/dissectors/packet-gsm_r_uus1.c
@@ -429,7 +429,7 @@ de_gsm_r_uus1_elda(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo _U_, guin
curr_offset += 3;
- /* Longtitude */
+ /* Longitude */
long_item = proto_tree_add_item(sub_tree, hf_gsm_r_uus1_elda_long, tvb, curr_offset, 4, ENC_NA);
long_tree = proto_item_add_subtree(long_item, ett_gsm_r_uus1_elda_long);
@@ -448,7 +448,7 @@ de_gsm_r_uus1_elda(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo _U_, guin
proto_tree_add_uint_format_value(long_tree, hf_gsm_r_uus1_elda_long_sec, tvb, curr_offset, 4, val, "%.2f", (float)(long_sec_val)/100);
proto_tree_add_boolean(long_tree, hf_gsm_r_uus1_elda_long_hem, tvb, curr_offset, 4, val);
- proto_item_set_text(long_item, "Longtitude: %d %d\'%.2f\"%s", long_deg_val, long_min_val, (float)(long_sec_val)/100,
+ proto_item_set_text(long_item, "Longitude: %d %d\'%.2f\"%s", long_deg_val, long_min_val, (float)(long_sec_val)/100,
long_hem_val ? "W" : "E");
curr_offset += 3;
@@ -742,7 +742,7 @@ proto_register_gsm_r_uus1(void)
NULL, HFILL }
},
{ &hf_gsm_r_uus1_elda_lat,
- { "Lattitude", "gsm-r-uus1.elda.lat",
+ { "Latitude", "gsm-r-uus1.elda.lat",
FT_NONE, BASE_NONE, NULL, 0x0,
NULL, HFILL }
},
@@ -767,7 +767,7 @@ proto_register_gsm_r_uus1(void)
NULL, HFILL }
},
{ &hf_gsm_r_uus1_elda_long,
- { "Lattitude", "gsm-r-uus1.elda.long",
+ { "Latitude", "gsm-r-uus1.elda.long",
FT_NONE, BASE_NONE, NULL, 0x0,
NULL, HFILL }
},
diff --git a/epan/dissectors/packet-hartip.c b/epan/dissectors/packet-hartip.c
index 81fc3f997a..4f972e9374 100644
--- a/epan/dissectors/packet-hartip.c
+++ b/epan/dissectors/packet-hartip.c
@@ -1505,7 +1505,7 @@ proto_register_hartip(void)
"Pass Through Preambles", HFILL }
},
{ &hf_hartip_pt_delimiter,
- { "Delimter", "hart_ip.pt.delimter",
+ { "Delimiter", "hart_ip.pt.delimiter",
FT_UINT8, BASE_HEX, NULL, 0x0,
"Pass Through Delimiter", HFILL }
},
@@ -2021,7 +2021,7 @@ proto_register_hartip(void)
/* command 16 and 19 */
{ &hf_hartip_pt_rsp_final_assembly_number,
- { "Final Assembly Number", "hart_ip.pt.rsp.final_assembly_numbe",
+ { "Final Assembly Number", "hart_ip.pt.rsp.final_assembly_number",
FT_BYTES, BASE_NONE, NULL, 0x0,
NULL, HFILL }
},
diff --git a/epan/dissectors/packet-iec104.c b/epan/dissectors/packet-iec104.c
index a83bf48eb6..abf084ceda 100644
--- a/epan/dissectors/packet-iec104.c
+++ b/epan/dissectors/packet-iec104.c
@@ -1892,7 +1892,7 @@ proto_register_iec60870_asdu(void)
{ &hf_causetx,
{ "CauseTx", "iec60870_asdu.causetx", FT_UINT8, BASE_DEC, VALS(causetx_types), F_CAUSE,
- "Cause of Transmision", HFILL }},
+ "Cause of Transmission", HFILL }},
{ &hf_nega,
{ "Negative", "iec60870_asdu.nega", FT_BOOLEAN, 8, NULL, F_NEGA,
diff --git a/epan/dissectors/packet-ieee1905.c b/epan/dissectors/packet-ieee1905.c
index de6048ba6e..f7b447cfe0 100644
--- a/epan/dissectors/packet-ieee1905.c
+++ b/epan/dissectors/packet-ieee1905.c
@@ -1117,7 +1117,7 @@ static value_string_ext ieee1905_message_type_vals_ext = VALUE_STRING_EXT_INIT(i
#define BSS_CONFIGURATION_REQUEST_TLV 0xBB
#define PROFILE_2_ERROR_CODE_ERROR_TLV 0xBC
#define BSS_CONFIGURATION_RESPONSE_TLV 0xBD /* FIX */
-#define AP_RADIO_ADVANCED_CAPABULITIES_TLV 0xBE
+#define AP_RADIO_ADVANCED_CAPABILITIES_TLV 0xBE
#define ASSOCIATION_STATUS_NOTIFICATON_TLV 0xBF
#define SOURCE_INFO_TLV 0xC0
#define TUNNELED_MESSAGE_TYPE_TLV 0xC1
@@ -1240,7 +1240,7 @@ static const value_string ieee1905_tlv_types_vals[] = {
{ BSS_CONFIGURATION_REQUEST_TLV, "BSS Configuration Request" },
{ PROFILE_2_ERROR_CODE_ERROR_TLV, "Profile 2 Error Code" },
{ BSS_CONFIGURATION_RESPONSE_TLV, "BSS Configuration Response" },
- { AP_RADIO_ADVANCED_CAPABULITIES_TLV, "AP Radio Advanced Capabilities" },
+ { AP_RADIO_ADVANCED_CAPABILITIES_TLV, "AP Radio Advanced Capabilities" },
{ ASSOCIATION_STATUS_NOTIFICATON_TLV, "Associated Status Notification" },
{ SOURCE_INFO_TLV, "Source Info" },
{ TUNNELED_MESSAGE_TYPE_TLV, "Tunneled Message Type" },
@@ -1509,13 +1509,13 @@ static const value_string channel_preference_prefs_vals[] = {
static const value_string channel_preference_reason_vals[] = {
{ 0x0, "Unspecified" },
{ 0x1, "Proximate non-802.11 interference in local environment" },
- { 0x2, "Intra-network 802.11 OBSS interfernece management" },
+ { 0x2, "Intra-network 802.11 OBSS interference management" },
{ 0x3, "External network 802.11 OBSS interference management" },
{ 0x4, "Reduced coverage (e.g. due to limited transmit power" },
{ 0x5, "Reduced throughput (e.g. due to limited channel bandwidth..." },
{ 0x6, "In-device interference within AP" },
{ 0x7, "Operation disallowed due to radar detection on a DFS channel" },
- { 0x8, "Operation would prevent backhaul operatoon uding shared radio" },
+ { 0x8, "Operation would prevent backhaul operation using shared radio" },
{ 0x9, "Immediate operation possible on a DFS channel" },
{ 0xA, "DFS channel state unknown" },
{ 0xB, "Controller DFS Channel Clear Indication" },
@@ -1539,7 +1539,7 @@ static const value_string ieee1905_steering_policy_vals[] = {
};
static const value_string ieee1905_error_code_vals[] = {
- { 0x01, "STA associated with a BSS operatted by the Agent" },
+ { 0x01, "STA associated with a BSS operated by the Agent" },
{ 0x02, "STA not associated with any BSS operated by the Agent" },
{ 0x03, "Client capability report undecified failure" },
{ 0x04, "Backhaul steering request rejected because station cannot operate on specified channel" },
@@ -5533,7 +5533,7 @@ static int * const ap_wf6_gen_flags[] = {
static const value_string ap_wf6_agent_role_vals[] = {
{ 0, "Wi-Fi 6 support info for the AP role" },
- { 1, "Wi-Fi 6 sypport info for the non-AP STA role" },
+ { 1, "Wi-Fi 6 support info for the non-AP STA role" },
{ 0, NULL }
};
@@ -8099,7 +8099,7 @@ dissect_ieee1905_tlv_data(tvbuff_t *tvb, packet_info *pinfo _U_,
offset = dissect_r2_error_code(tvb, pinfo, tree, offset, tlv_len);
break;
- case AP_RADIO_ADVANCED_CAPABULITIES_TLV:
+ case AP_RADIO_ADVANCED_CAPABILITIES_TLV:
offset = dissect_ap_radio_advanced_capabilities(tvb, pinfo, tree,
offset, tlv_len);
break;
@@ -8632,7 +8632,7 @@ proto_register_ieee1905(void)
FT_UINT32, BASE_DEC, NULL, 0, NULL, HFILL }},
{ &hf_ieee1905_mac_throughput_capacity,
- { "MAC througput capacity", "ieee1905.macThroughputCapacity",
+ { "MAC throughput capacity", "ieee1905.macThroughputCapacity",
FT_UINT16, BASE_DEC, NULL, 0, NULL, HFILL }},
{ &hf_ieee1905_link_availability,
@@ -8940,7 +8940,7 @@ proto_register_ieee1905(void)
FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
{ &hf_ieee1905_ap_local_intf_ssid,
- { "AP operational BSS local interfase SSID", "ieee1905.ap_bss_local_intf_ssid",
+ { "AP operational BSS local interface SSID", "ieee1905.ap_bss_local_intf_ssid",
FT_STRING, BASE_NONE, NULL, 0, NULL, HFILL }},
{ &hf_ieee1905_ap_capabilities_flags,
@@ -9668,7 +9668,7 @@ proto_register_ieee1905(void)
FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
{ &hf_ieee1905_btm_steering_disallowed_mac_addr,
- { "Local steering disallowed MAC address", "ieee1905.steering_policy.local_disalow_mac_addr",
+ { "Local steering disallowed MAC address", "ieee1905.steering_policy.local_disallow_mac_addr",
FT_ETHER, BASE_NONE, NULL, 0, NULL, HFILL }},
{ &hf_ieee1905_steering_policy_radio_count,
@@ -9836,7 +9836,7 @@ proto_register_ieee1905(void)
FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
{ &hf_ieee1905_measurement_report,
- { "Measurement Report", "ieee1905.meaurement_report",
+ { "Measurement Report", "ieee1905.measurement_report",
FT_BYTES, BASE_NONE, NULL, 0, NULL, HFILL }},
{ &hf_ieee1905_beacon_metrics_response_mac_addr,
@@ -9941,7 +9941,7 @@ proto_register_ieee1905(void)
FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
{ &hf_ieee1905_channel_scan_capa_oper_class,
- { "Operating Class", "ieee1905.channel_scan_capabulities.operating_class",
+ { "Operating Class", "ieee1905.channel_scan_capabilities.operating_class",
FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
{ &hf_ieee1905_channel_scan_capa_oper_class_chan_cnt,
@@ -10113,7 +10113,7 @@ proto_register_ieee1905(void)
FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
{ &hf_ieee1905_channel_scan_result_sta_count,
- { "Station Cound", "ieee1905.channel_scan_result.station_count",
+ { "Station Count", "ieee1905.channel_scan_result.station_count",
FT_UINT16, BASE_DEC, NULL, 0, NULL, HFILL }},
{ &hf_ieee1905_channel_scan_result_neigh_reserved,
@@ -10542,7 +10542,7 @@ proto_register_ieee1905(void)
{ &hf_ieee1905_cac_status_rpt_non_occ_op_class,
{ "Operating Class",
- "ieee1905.cac_status_report.non_occupoied_channel.operating_class",
+ "ieee1905.cac_status_report.non_occupied_channel.operating_class",
FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }},
{ &hf_ieee1905_cac_status_rpt_non_occ_channel,
diff --git a/epan/dissectors/packet-ieee80211.c b/epan/dissectors/packet-ieee80211.c
index 315e469716..ab1e81597c 100644
--- a/epan/dissectors/packet-ieee80211.c
+++ b/epan/dissectors/packet-ieee80211.c
@@ -5606,8 +5606,8 @@ static int hf_ieee80211_tag_tspec_tsconst_start_time = -1;
static int hf_ieee80211_tag_tspec_tsconst_duration = -1;
static int hf_ieee80211_tag_tspec_tsconst_period = -1;
static int hf_ieee80211_tag_tspec_tsconst_interferer_mac = -1;
-static int hf_ieee80211_tag_channel_measurement_feedback_realtive_I = -1;
-static int hf_ieee80211_tag_channel_measurement_feedback_realtive_Q = -1;
+static int hf_ieee80211_tag_channel_measurement_feedback_relative_I = -1;
+static int hf_ieee80211_tag_channel_measurement_feedback_relative_Q = -1;
static int hf_ieee80211_tag_channel_measurement_feedback_tap_delay = -1;
static int hf_ieee80211_tag_channel_measurement_feedback_sector_id = -1;
static int hf_ieee80211_tag_channel_measurement_feedback_antenna_id = -1;
@@ -23492,9 +23492,9 @@ ieee80211_tag_channel_measurement_fb(tvbuff_t *tvb, packet_info *pinfo, proto_tr
while(num_measurement > 0) {
proto_tree_add_item(tree, hf_ieee80211_ff_snr, tvb, offset, 1, ENC_NA);
offset += 1;
- proto_tree_add_item(tree, hf_ieee80211_tag_channel_measurement_feedback_realtive_I, tvb, offset, 1, ENC_NA);
+ proto_tree_add_item(tree, hf_ieee80211_tag_channel_measurement_feedback_relative_I, tvb, offset, 1, ENC_NA);
offset += 1;
- proto_tree_add_item(tree, hf_ieee80211_tag_channel_measurement_feedback_realtive_Q, tvb, offset, 1, ENC_NA);
+ proto_tree_add_item(tree, hf_ieee80211_tag_channel_measurement_feedback_relative_Q, tvb, offset, 1, ENC_NA);
offset += 1;
proto_tree_add_item(tree, hf_ieee80211_tag_channel_measurement_feedback_tap_delay, tvb, offset, 1, ENC_NA);
offset += 1;
@@ -29879,13 +29879,13 @@ proto_register_ieee80211(void)
FT_ETHER, BASE_NONE, NULL, 0,
NULL, HFILL }},
- {&hf_ieee80211_tag_channel_measurement_feedback_realtive_I,
- {"Channel Measurement Feedback Relative I", "wlan.ch_meas_fb.realtive_I",
+ {&hf_ieee80211_tag_channel_measurement_feedback_relative_I,
+ {"Channel Measurement Feedback Relative I", "wlan.ch_meas_fb.relative_I",
FT_UINT8, BASE_DEC, NULL, 0,
NULL, HFILL }},
- {&hf_ieee80211_tag_channel_measurement_feedback_realtive_Q,
- {"Channel Measurement Feedback Relative Q", "wlan.ch_meas_fb.realtive_Q",
+ {&hf_ieee80211_tag_channel_measurement_feedback_relative_Q,
+ {"Channel Measurement Feedback Relative Q", "wlan.ch_meas_fb.relative_Q",
FT_UINT8, BASE_DEC, NULL, 0,
NULL, HFILL }},
@@ -36719,7 +36719,7 @@ proto_register_ieee80211(void)
{&hf_ieee80211_he_qtp_request_dialog_token,
{"Dialog Token", "wlan.ext_tag.quiet_time_period.request.dialog_token",
FT_UINT16, BASE_DEC, NULL, 0,
- "Quite Time Periords Response suptype to which request subtype corresponds",
+ "Quiet Time Periods Response suptype to which request subtype corresponds",
HFILL } },
{&hf_ieee80211_he_qtp_request_quiet_period_offset,
@@ -37251,7 +37251,7 @@ proto_register_ieee80211(void)
FT_BOOLEAN, 16, TFS(&tfs_enabled_disabled), 0x200, NULL, HFILL }},
{&hf_ieee80211_osen_rsn_cap_flags,
- {"RSN Capability Flags", "wlan.osen.rsn.cabailities.flags",
+ {"RSN Capability Flags", "wlan.osen.rsn.capabilities.flags",
FT_UINT16, BASE_HEX, NULL, 0, NULL, HFILL }},
{&hf_ieee80211_osen_rsn_spp_a_msdu_capable,
diff --git a/epan/dissectors/packet-infiniband.c b/epan/dissectors/packet-infiniband.c
index 5c16485563..6b60a374a1 100644
--- a/epan/dissectors/packet-infiniband.c
+++ b/epan/dissectors/packet-infiniband.c
@@ -239,7 +239,7 @@ static const value_string SUBM_Attributes[] = {
{ 0x0014, "Attribute (GUIDInfo)"},
{ 0x0015, "Attribute (PortInfo)"},
{ 0x0016, "Attribute (P_KeyTable)"},
- { 0x0017, "Attribute (SLtoVLMapptingTable)"},
+ { 0x0017, "Attribute (SLtoVLMappingTable)"},
{ 0x0018, "Attribute (VLArbitrationTable)"},
{ 0x0019, "Attribute (LinearForwardingTable)"},
{ 0x001A, "Attribute (RandomForwardingTable)"},
diff --git a/epan/dissectors/packet-isakmp.c b/epan/dissectors/packet-isakmp.c
index 5755f47642..d9ebe8b922 100644
--- a/epan/dissectors/packet-isakmp.c
+++ b/epan/dissectors/packet-isakmp.c
@@ -7806,7 +7806,7 @@ proto_register_isakmp(void)
FT_UINT16, BASE_DEC, NULL, 0x0,
NULL, HFILL }},
{ &hf_isakmp_kd_payload,
- { "Key Download Paket", "isakmp.kd.payload",
+ { "Key Download Payload", "isakmp.kd.payload",
FT_NONE, BASE_NONE, NULL, 0x0,
NULL, HFILL }},
{ &hf_isakmp_kdp_type,
diff --git a/epan/dissectors/packet-isis-lsp.c b/epan/dissectors/packet-isis-lsp.c
index 805da23b9e..5ad31f3dc7 100644
--- a/epan/dissectors/packet-isis-lsp.c
+++ b/epan/dissectors/packet-isis-lsp.c
@@ -5564,7 +5564,7 @@ proto_register_isis_lsp(void)
NULL, HFILL }
},
{ &hf_isis_lsp_srv6_loc_alg,
- { "Algorithm", "isis.lsp.srv6_locator.algorighm",
+ { "Algorithm", "isis.lsp.srv6_locator.algorithm",
FT_UINT8, BASE_DEC, VALS(isis_igp_alg_vals), 0x0,
NULL, HFILL }
},
diff --git a/epan/dissectors/packet-isis.c b/epan/dissectors/packet-isis.c
index ddae0b18b8..c872d7472d 100644
--- a/epan/dissectors/packet-isis.c
+++ b/epan/dissectors/packet-isis.c
@@ -161,7 +161,7 @@ proto_register_isis(void)
{
static hf_register_info hf[] = {
{ &hf_isis_irpd,
- { "Intradomain Routeing Protocol Discriminator", "isis.irpd",
+ { "Intradomain Routing Protocol Discriminator", "isis.irpd",
FT_UINT8, BASE_HEX, VALS(nlpid_vals), 0x0, NULL, HFILL }},
{ &hf_isis_header_length,
diff --git a/epan/dissectors/packet-jdwp.c b/epan/dissectors/packet-jdwp.c
index 85f8d2bb92..b88ced60d5 100644
--- a/epan/dissectors/packet-jdwp.c
+++ b/epan/dissectors/packet-jdwp.c
@@ -235,7 +235,7 @@ static const value_string commandset_threadreference[] = {
{11, "Interrupt"},
{12, "SuspendCount"},
{13, "OwnedMonitorsStackDepthInfo"},
- {14, "ForceEearlyReturn"},
+ {14, "ForceEarlyReturn"},
{0, NULL}
};
diff --git a/epan/dissectors/packet-ldp.c b/epan/dissectors/packet-ldp.c
index 13f9fd86a6..45e8699c6d 100644
--- a/epan/dissectors/packet-ldp.c
+++ b/epan/dissectors/packet-ldp.c
@@ -956,7 +956,7 @@ static const value_string tlv_status_data[] = {
{ 0x00000005, "Bad Message Length" },
{ 0x00000006, "Unknown TLV" },
{ 0x00000007, "Bad TLV Length" },
- { 0x00000008, "Malformted TLV Value" },
+ { 0x00000008, "Malformed TLV Value" },
{ 0x00000009, "Hold Timer Expired" },
{ 0x0000000A, "Shutdown" },
{ 0x0000000B, "Loop Detected" },
diff --git a/epan/dissectors/packet-lldp.c b/epan/dissectors/packet-lldp.c
index f1cc528acc..c982423e61 100644
--- a/epan/dissectors/packet-lldp.c
+++ b/epan/dissectors/packet-lldp.c
@@ -4782,7 +4782,7 @@ proto_register_lldp(void)
VALS(dcbx_protocol_types), 0x0, "Unknown", HFILL }
},
{ &hf_dcbx_control_sequence,
- { "Sequence No", "lldp.dcbx.contol.seq", FT_UINT32, BASE_DEC,
+ { "Sequence No", "lldp.dcbx.control.seq", FT_UINT32, BASE_DEC,
NULL, 0, NULL, HFILL }
},
{ &hf_dcbx_control_ack,
diff --git a/epan/dissectors/packet-llrp.c b/epan/dissectors/packet-llrp.c
index b115456cdf..989f213762 100644
--- a/epan/dissectors/packet-llrp.c
+++ b/epan/dissectors/packet-llrp.c
@@ -742,7 +742,7 @@ static value_string_ext tv_type_ext = VALUE_STRING_EXT_INIT(tv_type);
static const range_string protocol_id[] = {
{ LLRP_PROT_ID_UNSPECIFIED, LLRP_PROT_ID_UNSPECIFIED, "Unspecified protocol" },
{ LLRP_PROT_ID_EPC_C1G2, LLRP_PROT_ID_EPC_C1G2, "EPCGlobal Class 1 Gen 2" },
- { LLRP_PROT_ID_EPC_C1G2 + 1, 255, "Reserved for furure use" },
+ { LLRP_PROT_ID_EPC_C1G2 + 1, 255, "Reserved for future use" },
{ 0, 0, NULL }
};
@@ -1293,7 +1293,7 @@ static const value_string impinj_access_range[] = {
static const value_string impinj_persistence[] = {
{ LLRP_IMPINJ_PERSISTENCE_UNKNOWN, "Unknown" },
{ LLRP_IMPINJ_PERSISTENCE_TEMPORARY, "Temporary" },
- { LLRP_IMPINJ_PERSISTENCE_PERMANENT, "Permament" },
+ { LLRP_IMPINJ_PERSISTENCE_PERMANENT, "Permanent" },
{ 0, NULL }
};
diff --git a/epan/dissectors/packet-lnet.c b/epan/dissectors/packet-lnet.c
index 8e5d11b100..319c40e6c9 100644
--- a/epan/dissectors/packet-lnet.c
+++ b/epan/dissectors/packet-lnet.c
@@ -967,7 +967,7 @@ proto_register_lnet(void)
{ "Payload", "lnet.payload", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL }},
{ &hf_dst_wmd_interface,
- { "DST MD index interface", "lnet.msg_dst_inteface_cookie", FT_UINT64, BASE_HEX_DEC, NULL, 0x0, NULL, HFILL }},
+ { "DST MD index interface", "lnet.msg_dst_interface_cookie", FT_UINT64, BASE_HEX_DEC, NULL, 0x0, NULL, HFILL }},
{ &hf_dst_wmd_object,
{ "DST MD index object", "lnet.msg_dst_object_cookie", FT_UINT64, BASE_HEX_DEC, NULL, 0x0, NULL, HFILL }},
{ &hf_match_bits,
diff --git a/epan/dissectors/packet-docsis.c b/epan/dissectors/packet-docsis.c
index 76208025bb..7fb36c0343 100644
--- a/epan/dissectors/packet-docsis.c
+++ b/epan/dissectors/packet-docsis.c
@@ -523,7 +523,7 @@ dissect_encrypted_frame (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree,
// tvbuff_t *next_tvb;
/* According to CM-SP-SEC-v3.1, PDU regions of the following
* frames must be encryped when security is enabled:
* - Variable-length PDU MAC Frames;
* - Fragmentation MAC Frames;
* - Registration Request (REG-REQ-MP) MAC Management Message Frames;
@@ -1166,7 +1166,7 @@ proto_register_docsis (void)
{ &hf_docsis_encrypted_payload,
{ "Encrypted Payload", "docsis.encrypted_payload",
FT_BYTES, BASE_NONE, NULL, 0x0,
- "Encryped data", HFILL }
+ "Encrypted data", HFILL }
}
};
@@ -523,7 +523,7 @@ dissect_encrypted_frame (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree,
// tvbuff_t *next_tvb;
/* According to CM-SP-SEC-v3.1, PDU regions of the following
- * frames must be encryped when security is enabled:
+ * frames must be encrypted when security is enabled:
* - Variable-length PDU MAC Frames;
* - Fragmentation MAC Frames;